A comfortable wrapper for HTTP requests: the JavaScript fetch API on
wasm, and a streaming reqwest client natively — one API for both.
Structs
- Abort
Controller - Abort
Signal - Client
- Main client for making HTTP requests
- Request
Builder - A builder for HTTP requests
- Response
- A response from a fetch request. Headers are available immediately; the body streams from the socket as it is read.
- Stream
Reader - A reader for streaming response bodies chunk by chunk
Enums
- Error
- Errors that can occur when making a request
- Method
- HTTP methods
- Request
Mode - The
RequestModeenum.
Functions
- get
- Convenience function for making a GET request
- post_
json - Convenience function for making a POST request with JSON body